# Example Package

INTRODUCTION
------------

This is a simple distributions package containing the following files:

 * A Generic distribution class for calculating and 
   visualizing a probability distribution.

 * A Gaussian distribution class for calculating and visualizing a Gaussian distribution.
   
   Attributes:
   mean (float) representing the mean value of the distribution
   stdev (float) representing the standard deviation of the distribution
   data_list (list of floats) a list of floats extracted from the data file

 * A Binomial distribution class for calculating and 
    visualizing a Binomial distribution.
    
    Attributes:
        mean (float) representing the mean value of the distribution
        stdev (float) representing the standard deviation of the distribution
        data_list (list of floats) a list of floats to be extracted from the data file
        p (float) representing the probability of an event occurring
        n (int) number of trials
   
   
REQUIREMENTS
------------

This module requires no modules.

INSTALLATION
------------

 * Install as you would normally install a contributed module.
   
CONFIGURATION
-------------

The module has no menu or modifiable settings. There is no configuration. When
enabled, the module will prevent the links from appearing. To get the links
back, disable the module and clear caches.


